==> parodia_admin-1.0.2.tar.gz: lib/core/repository/productCatalog.repository.dart <==
// GET
// /api/v1/dashboard/catalogs/products

// POST
// /api/v1/dashboard/catalogs/products

// POST
// /api/v1/dashboard/catalogs/products/multiple

// PUT
// /api/v1/dashboard/catalogs/products/{id}

// DELETE
// /api/v1/dashboard/catalogs/products/{id}

// POST
// /api/v1/dashboard/catalogs/products/{id}/recover
import 'package:parodia_admin/core/dto/product_catalog.dto.dart';
import 'package:parodia_admin/core/dto/response_item.dto.dart';
import 'package:parodia_admin/core/dto/response_list.dto.dart';
import 'package:parodia_admin/core/enums.dart';
import 'package:parodia_admin/core/http/parodia_http.dart';
import 'package:parodia_admin/core/model/body_data.model.dart';
import 'package:parodia_admin/core/model/query.model.dart';

class ProductCatalogRepository {
  ParodiaHTTP? _http;

  ProductCatalogRepository(ParodiaHTTP http) {
    _http = http;
  }

  Future<ResponseItemDTO<ProductCatalogDTO>> getById({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/catalogs/products',
      param: id,
    );

    return ResponseItemDTO<ProductCatalogDTO>(
      response: response,
      fromJson: ProductCatalogDTO.fromJson,
    );
  }

  Future<ResponseListDTO<ProductCatalogDTO>> getAll({ProductCatalogQuery? query}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/catalogs/products',
      query: query,
    );

    return ResponseListDTO<ProductCatalogDTO>(
      response: response,
      fromJson: ProductCatalogDTO.fromJson,
    );
  }

  Future<ResponseItemDTO> create({ProductCatalogBody? productCatalog}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/catalogs/products',
      data: productCatalog,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> multiple(
      {String? id, ProductCatalogMultipleBody? productCatalogs}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/catalogs/products/multiple',
      data: productCatalogs,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> update(
      {String? id, ProductCatalogBody? productCatalog}) async {
    final response = await _http!.request(
      requestType: RequestType.put,
      path: '/catalogs/products',
      param: id,
      data: productCatalog,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> delete({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.delete,
      path: '/catalogs/products',
      param: id,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> recover({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/catalogs/products/$id/recover',
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }
}

==> parodia_admin-1.0.20.tar.gz: lib/core/repository/productCatalog.repository.dart <==
// GET
// /api/v1/dashboard/dashboard/catalogs/products

// POST
// /api/v1/dashboard/dashboard/catalogs/products

// POST
// /api/v1/dashboard/dashboard/catalogs/products/multiple

// PUT
// /api/v1/dashboard/dashboard/catalogs/products/{id}

// DELETE
// /api/v1/dashboard/dashboard/catalogs/products/{id}

// POST
// /api/v1/dashboard/dashboard/catalogs/products/{id}/recover
import 'package:parodia_admin/core/dto/product_catalog.dto.dart';
import 'package:parodia_admin/core/dto/response_item.dto.dart';
import 'package:parodia_admin/core/dto/response_list.dto.dart';
import 'package:parodia_admin/core/enums.dart';
import 'package:parodia_admin/core/http/parodia_http.dart';
import 'package:parodia_admin/core/model/body_data.model.dart';
import 'package:parodia_admin/core/model/query.model.dart';

class ProductCatalogRepository {
  ParodiaHTTP? _http;

  ProductCatalogRepository(ParodiaHTTP http) {
    _http = http;
  }

  Future<ResponseItemDTO<ProductCatalogDTO>> getById({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/dashboard/catalogs/products',
      param: id,
    );

    return ResponseItemDTO<ProductCatalogDTO>(
      response: response,
      fromJson: ProductCatalogDTO.fromJson,
    );
  }

  Future<ResponseListDTO<ProductCatalogDTO>> getAll({ProductCatalogQuery? query}) async {
    final response = await _http!.request(
      requestType: RequestType.get,
      path: '/dashboard/catalogs/products',
      query: query,
    );

    return ResponseListDTO<ProductCatalogDTO>(
      response: response,
      fromJson: ProductCatalogDTO.fromJson,
    );
  }

  Future<ResponseItemDTO> create({ProductCatalogBody? productCatalog}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/catalogs/products',
      data: productCatalog,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> multiple(
      {String? id, ProductCatalogMultipleBody? productCatalogs}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/catalogs/products/multiple',
      data: productCatalogs,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> update(
      {String? id, ProductCatalogBody? productCatalog}) async {
    final response = await _http!.request(
      requestType: RequestType.put,
      path: '/dashboard/catalogs/products',
      param: id,
      data: productCatalog,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> delete({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.delete,
      path: '/dashboard/catalogs/products',
      param: id,
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }

  Future<ResponseItemDTO> recover({String? id}) async {
    final response = await _http!.request(
      requestType: RequestType.post,
      path: '/dashboard/catalogs/products/$id/recover',
    );

    return ResponseItemDTO(
      response: response,
      fromJson: null,
    );
  }
}
